@@ -3,6 +3,8 @@
 
 #include <glib.h>
 
+G_BEGIN_DECLS
+
 #ifdef ORBIT2_INTERNAL_API
 
 typedef enum {
@@ -16,4 +18,6 @@ void ORBit_genuid_buffer (guchar *buffer, int length);
 
 #endif /* ORBIT2_INTERNAL_API */
 
+G_END_DECLS
+
 #endif /* ORBIT_GENRAND_H */
